pub struct HashedStorageSorted {
pub storage_slots: Vec<(B256, U256)>,
}Expand description
Sorted hashed storage optimized for iterating during state trie calculation.
Fields
storage_slots: Vec<(B256, U256)>Sorted collection of updated storage slots. [U256::ZERO] indicates a deleted value.
Implementations
Sourceimpl HashedStorageSorted
impl HashedStorageSorted
Sourcepub fn storage_slots_ref(&self) -> &[(B256, U256)]
pub fn storage_slots_ref(&self) -> &[(B256, U256)]
Returns reference to updated storage slots.
Sourcepub fn extend_ref(&mut self, other: &Self)
pub fn extend_ref(&mut self, other: &Self)
Extends the storage slots updates with another set of sorted updates.
Sourcepub fn merge_batch<'a>(updates: impl IntoIterator<Item = &'a Self>) -> Self
pub fn merge_batch<'a>(updates: impl IntoIterator<Item = &'a Self>) -> Self
Batch-merge sorted hashed storage. Iterator yields newest to oldest.