pub struct LazyHashedPostStateSorted { /* private fields */ }Expand description
Shared sorted hashed state, available immediately or published by a background task. Clones share the same result and wait for the producer when it is still pending.
Implementations
Sourceimpl LazyHashedPostStateSorted
impl LazyHashedPostStateSorted
Sourcepub fn ready(state: Arc<HashedPostStateSorted>) -> Self
pub fn ready(state: Arc<HashedPostStateSorted>) -> Self
Creates a handle to already sorted hashed state.
Sourcepub fn pending(
hashed_state: Arc<HashedPostState>,
) -> (Self, HashedPostStateSortedProducer)
Available on crate feature std only.
pub fn pending( hashed_state: Arc<HashedPostState>, ) -> (Self, HashedPostStateSortedProducer)
std only.Creates a handle and a producer that sorts and publishes the hashed state.
Sourcepub fn get(&self) -> &Arc<HashedPostStateSorted> ⓘ
pub fn get(&self) -> &Arc<HashedPostStateSorted> ⓘ
Returns the sorted hashed state, waiting for its producer if it is still pending.