pub struct TrieInputSorted {
pub nodes: Arc<TrieUpdatesSorted>,
pub state: Arc<HashedPostStateSorted>,
pub prefix_sets: TriePrefixSetsMut,
}Expand description
Sorted variant of TrieInput for efficient proof generation.
This type holds sorted versions of trie data structures, which eliminates the need for expensive sorting operations during multiproof generation.
Fields
nodes: Arc<TrieUpdatesSorted>Sorted cached in-memory intermediate trie nodes.
state: Arc<HashedPostStateSorted>Sorted in-memory overlay hashed state.
prefix_sets: TriePrefixSetsMutPrefix sets for computation.
Implementations
Sourceimpl TrieInputSorted
impl TrieInputSorted
Sourcepub const fn new(
nodes: Arc<TrieUpdatesSorted>,
state: Arc<HashedPostStateSorted>,
prefix_sets: TriePrefixSetsMut,
) -> Self
pub const fn new( nodes: Arc<TrieUpdatesSorted>, state: Arc<HashedPostStateSorted>, prefix_sets: TriePrefixSetsMut, ) -> Self
Create new sorted trie input.
Sourcepub fn from_state(state: HashedPostStateSorted) -> Self
pub fn from_state(state: HashedPostStateSorted) -> Self
Create new sorted trie input from sorted in-memory state. The prefix sets will be constructed and set automatically.
Sourcepub fn from_unsorted(input: TrieInput) -> Self
pub fn from_unsorted(input: TrieInput) -> Self
Create from unsorted TrieInput by sorting.