pub struct ProofV2Target {
pub key_nibbles: Nibbles,
pub min_len: u8,
}Expand description
Target describes a proof target. For every proof target given, a proof calculator will calculate
and return all nodes whose path is a prefix of the target’s key_nibbles.
Fields
key_nibbles: NibblesThe key of the proof target, as nibbles.
min_len: u8The minimum length of a node’s path for it to be retained.
Implementations
Sourceimpl ProofV2Target
impl ProofV2Target
Sourcepub fn new(key: B256) -> Self
pub fn new(key: B256) -> Self
Returns a new ProofV2Target which matches all trie nodes whose path is a prefix of this
key.
Sourcepub fn with_min_len(self, min_len: u8) -> Self
pub fn with_min_len(self, min_len: u8) -> Self
Only match trie nodes whose path is at least this long.
Panics
This method panics if min_len is greater than 64.